@@ -576,5 +576,14 @@ class OSM:
         """
         return [line for line in self.railway_lines if re.search(r'\b{0}\b'.format(name), line.name)]
 
+    def reset_way_attributes(self):
+        """ Deletes all attributes of each way. E.g results are saved
+
+        """
+        for w in self.ways:
+            w.attributes = {}
+
     def __repr__(self):
         return "OSM region with bounding boxes: %s" % (str(self.bbox))
+
+
